==> zio-aws-computeoptimizer_2.13-7.21.15.7-sources.jar: zio/aws/computeoptimizer/model/GetEcsServiceRecommendationsRequest.scala <==
package zio.aws.computeoptimizer.model
import zio.aws.computeoptimizer.model.primitives.{
  AccountId,
  MaxResults,
  NextToken,
  ServiceArn
}
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import java.lang.Integer
import scala.jdk.CollectionConverters._
final case class GetEcsServiceRecommendationsRequest(
    serviceArns: Optional[Iterable[ServiceArn]] = Optional.Absent,
    nextToken: Optional[NextToken] = Optional.Absent,
    maxResults: Optional[MaxResults] = Optional.Absent,
    filters: Optional[
      Iterable[zio.aws.computeoptimizer.model.ECSServiceRecommendationFilter]
    ] = Optional.Absent,
    accountIds: Optional[Iterable[AccountId]] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.computeoptimizer.model.GetEcsServiceRecommendationsRequest = {
    import GetEcsServiceRecommendationsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.computeoptimizer.model.GetEcsServiceRecommendationsRequest
      .builder()
      .optionallyWith(
        serviceArns.map(value =>
          value.map { item =>
            ServiceArn.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.serviceArns)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .optionallyWith(
        maxResults.map(value => MaxResults.unwrap(value): Integer)
      )(_.maxResults)
      .optionallyWith(
        filters.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.filters)
      .optionallyWith(
        accountIds.map(value =>
          value.map { item =>
            AccountId.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.accountIds)
      .build()
  }
  def asReadOnly
      : zio.aws.computeoptimizer.model.GetEcsServiceRecommendationsRequest.ReadOnly =
    zio.aws.computeoptimizer.model.GetEcsServiceRecommendationsRequest
      .wrap(buildAwsValue())
}
object GetEcsServiceRecommendationsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.computeoptimizer.model.GetEcsServiceRecommendationsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.computeoptimizer.model.GetEcsServiceRecommendationsRequest =
      zio.aws.computeoptimizer.model.GetEcsServiceRecommendationsRequest(
        serviceArns.map(value => value),
        nextToken.map(value => value),
        maxResults.map(value => value),
        filters.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        accountIds.map(value => value)
      )
    def serviceArns: Optional[List[ServiceArn]]
    def nextToken: Optional[NextToken]
    def maxResults: Optional[MaxResults]
    def filters: Optional[List[
      zio.aws.computeoptimizer.model.ECSServiceRecommendationFilter.ReadOnly
    ]]
    def accountIds: Optional[List[AccountId]]
    def getServiceArns: ZIO[Any, AwsError, List[ServiceArn]] =
      AwsError.unwrapOptionField("serviceArns", serviceArns)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getMaxResults: ZIO[Any, AwsError, MaxResults] =
      AwsError.unwrapOptionField("maxResults", maxResults)
    def getFilters: ZIO[Any, AwsError, List[
      zio.aws.computeoptimizer.model.ECSServiceRecommendationFilter.ReadOnly
    ]] = AwsError.unwrapOptionField("filters", filters)
    def getAccountIds: ZIO[Any, AwsError, List[AccountId]] =
      AwsError.unwrapOptionField("accountIds", accountIds)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.computeoptimizer.model.GetEcsServiceRecommendationsRequest
  ) extends zio.aws.computeoptimizer.model.GetEcsServiceRecommendationsRequest.ReadOnly {
    override val serviceArns: Optional[List[ServiceArn]] = zio.aws.core.internal
      .optionalFromNullable(impl.serviceArns())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.computeoptimizer.model.primitives.ServiceArn(item)
        }.toList
      )
    override val nextToken: Optional[NextToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.computeoptimizer.model.primitives.NextToken(value))
    override val maxResults: Optional[MaxResults] = zio.aws.core.internal
      .optionalFromNullable(impl.maxResults())
      .map(value => zio.aws.computeoptimizer.model.primitives.MaxResults(value))
    override val filters: Optional[List[
      zio.aws.computeoptimizer.model.ECSServiceRecommendationFilter.ReadOnly
    ]] = zio.aws.core.internal
      .optionalFromNullable(impl.filters())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.computeoptimizer.model.ECSServiceRecommendationFilter
            .wrap(item)
        }.toList
      )
    override val accountIds: Optional[List[AccountId]] = zio.aws.core.internal
      .optionalFromNullable(impl.accountIds())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.computeoptimizer.model.primitives.AccountId(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.computeoptimizer.model.GetEcsServiceRecommendationsRequest
  ): zio.aws.computeoptimizer.model.GetEcsServiceRecommendationsRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-computeoptimizer_3-5.19.7.5-sources.jar: zio/aws/computeoptimizer/model/GetEcsServiceRecommendationsRequest.scala <==
package zio.aws.computeoptimizer.model
import zio.aws.computeoptimizer.model.primitives.{
  AccountId,
  MaxResults,
  NextToken,
  ServiceArn
}
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import java.lang.Integer
import scala.jdk.CollectionConverters.*
final case class GetEcsServiceRecommendationsRequest(
    serviceArns: Optional[Iterable[ServiceArn]] = Optional.Absent,
    nextToken: Optional[NextToken] = Optional.Absent,
    maxResults: Optional[MaxResults] = Optional.Absent,
    filters: Optional[
      Iterable[zio.aws.computeoptimizer.model.ECSServiceRecommendationFilter]
    ] = Optional.Absent,
    accountIds: Optional[Iterable[AccountId]] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.computeoptimizer.model.GetEcsServiceRecommendationsRequest = {
    import GetEcsServiceRecommendationsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.computeoptimizer.model.GetEcsServiceRecommendationsRequest
      .builder()
      .optionallyWith(
        serviceArns.map(value =>
          value.map { item =>
            ServiceArn.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.serviceArns)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .optionallyWith(
        maxResults.map(value => MaxResults.unwrap(value): Integer)
      )(_.maxResults)
      .optionallyWith(
        filters.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.filters)
      .optionallyWith(
        accountIds.map(value =>
          value.map { item =>
            AccountId.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.accountIds)
      .build()
  }
  def asReadOnly
      : zio.aws.computeoptimizer.model.GetEcsServiceRecommendationsRequest.ReadOnly =
    zio.aws.computeoptimizer.model.GetEcsServiceRecommendationsRequest
      .wrap(buildAwsValue())
}
object GetEcsServiceRecommendationsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.computeoptimizer.model.GetEcsServiceRecommendationsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.computeoptimizer.model.GetEcsServiceRecommendationsRequest =
      zio.aws.computeoptimizer.model.GetEcsServiceRecommendationsRequest(
        serviceArns.map(value => value),
        nextToken.map(value => value),
        maxResults.map(value => value),
        filters.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        accountIds.map(value => value)
      )
    def serviceArns: Optional[List[ServiceArn]]
    def nextToken: Optional[NextToken]
    def maxResults: Optional[MaxResults]
    def filters: Optional[List[
      zio.aws.computeoptimizer.model.ECSServiceRecommendationFilter.ReadOnly
    ]]
    def accountIds: Optional[List[AccountId]]
    def getServiceArns: ZIO[Any, AwsError, List[ServiceArn]] =
      AwsError.unwrapOptionField("serviceArns", serviceArns)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getMaxResults: ZIO[Any, AwsError, MaxResults] =
      AwsError.unwrapOptionField("maxResults", maxResults)
    def getFilters: ZIO[Any, AwsError, List[
      zio.aws.computeoptimizer.model.ECSServiceRecommendationFilter.ReadOnly
    ]] = AwsError.unwrapOptionField("filters", filters)
    def getAccountIds: ZIO[Any, AwsError, List[AccountId]] =
      AwsError.unwrapOptionField("accountIds", accountIds)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.computeoptimizer.model.GetEcsServiceRecommendationsRequest
  ) extends zio.aws.computeoptimizer.model.GetEcsServiceRecommendationsRequest.ReadOnly {
    override val serviceArns: Optional[List[ServiceArn]] = zio.aws.core.internal
      .optionalFromNullable(impl.serviceArns())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.computeoptimizer.model.primitives.ServiceArn(item)
        }.toList
      )
    override val nextToken: Optional[NextToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.computeoptimizer.model.primitives.NextToken(value))
    override val maxResults: Optional[MaxResults] = zio.aws.core.internal
      .optionalFromNullable(impl.maxResults())
      .map(value => zio.aws.computeoptimizer.model.primitives.MaxResults(value))
    override val filters: Optional[List[
      zio.aws.computeoptimizer.model.ECSServiceRecommendationFilter.ReadOnly
    ]] = zio.aws.core.internal
      .optionalFromNullable(impl.filters())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.computeoptimizer.model.ECSServiceRecommendationFilter
            .wrap(item)
        }.toList
      )
    override val accountIds: Optional[List[AccountId]] = zio.aws.core.internal
      .optionalFromNullable(impl.accountIds())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.computeoptimizer.model.primitives.AccountId(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.computeoptimizer.model.GetEcsServiceRecommendationsRequest
  ): zio.aws.computeoptimizer.model.GetEcsServiceRecommendationsRequest.ReadOnly =
    new Wrapper(impl)
}
